@@ -53,7 +53,14 @@ def no_pyc():
 @command
 def version():
     'Display this version of Tango.'
-    print tango.__label__
+    # Derive version metadata from the distribution, to allow version labels to be
+    # maintained in one place within this project.  Version will be UNKNOWN if
+    # parsing the version from the distribution fails for any reason.
+    # This project depends on 'distribute' to provide pkg_resources.
+    try:
+        print __import__('pkg_resources').get_distribution('Tango').version
+    except Exception:
+        print 'UNKNOWN'
 
 
 @command
